/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.funambol.syncclient.ipod.panels;

import java.util.Hashtable;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.UIManager;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.border.*;
import javax.swing.SwingConstants;

import com.funambol.syncclient.ipod.MainWindow;
import com.funambol.syncclient.ipod.utils.Constants;
import com.funambol.syncclient.ipod.utils.Language;

/**
 * The Remote Synchronization settings window.
 *
 * @version $Id: RemoteSetPanel.java,v 1.1 2006/01/18 14:05:35 luigiafassina Exp $
 */
public class RemoteSetPanel extends JDialog
implements ActionListener, Constants {

    // ------------------------------------------------------------ Private Data
    private Hashtable  htFields = new Hashtable();
    private MainWindow mainWindow ;
    private JPanel     jpOver     ;
    private JPanel     jpUp       ;
    private JLabel     jLabel1    ;
    private JLabel     jLabel2    ;
    private JLabel     jLabel3    ;
    private JTextField jtContact  ;
    private JTextField jtCalendar ;
    private JTextField jtNote     ;
    private JButton    btOk       ;
    private JButton    btCancel   ;

    private Hashtable htContactValues  = null;
    private Hashtable htCalendarValues = null;
    private Hashtable htNoteValues     = null;

    // ---------------------------------------------------------- Public Methods

    /** Creates new form JDialog */
    public RemoteSetPanel(MainWindow mainWindow, boolean modal) {
        super(mainWindow, modal);
        this.mainWindow = mainWindow;

        htContactValues  = mainWindow.getXmlContactValues();
        htCalendarValues = mainWindow.getXmlCalendarValues();
        htNoteValues     = mainWindow.getXmlNoteValues();

        initComponents();
        setRemoteConfigStored();
    }

    /**
     * This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {
        int xlab  = 18 ;
        int wlab  = 80 ;
        int hlab  = 24 ;
        int xtext = 152;
        int wtext = 125;
        int htext = 21 ;
        int ybt   = 150;
        int wbt   = 88 ;
        int hbt   = 24 ;
        int y     = 22 ;
        int dy    = 23 ;

        jpOver     = new JPanel();
        jpUp       = new JPanel();
        jLabel1    = new JLabel();
        jLabel2    = new JLabel();
        jLabel3    = new JLabel();
        jtContact  = new JTextField();
        jtCalendar = new JTextField();
        jtNote     = new JTextField();
        btOk       = new JButton();
        btCancel   = new JButton();

        try {
            UIManager.setLookAndFeel(lookAndFeel);
        } catch(Exception e) {
            e.printStackTrace();
        }

        //
        // Set up the window.
        //
        getContentPane().setLayout(null);

        setTitle(Language.getMessage(Language.LABEL_TITLE_REMOTESET));
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setSize(310,218);
        setLocationRelativeTo(null);
        setFont(font);
        setName("remoteSetDialog");
        setResizable(false);

        jpOver.setLayout(null);
        jpOver.setBackground(Color.WHITE);
        jpOver.setForeground(Color.WHITE);
        jpOver.setBounds(0, 0, 310, 218);
        getContentPane().add(jpOver);

        //
        // Internal panel for Remote Settings
        //
        jpUp.setLayout(null);
        jpUp.setBounds(7, 15, 290, 115);
        jpUp.setBackground(Color.WHITE);
        jpUp.setBorder(new TitledBorder(
                            new LineBorder(new Color(204,204,204), 1, true),
                            Language.getMessage(Language.LABEL_TITLE_REMOTESET),
                            1,
                            0,
                            font,
                            new Color(0,51,204))
        );
        jpUp.setName("remoteSet");

        jLabel1.setText(Language.getMessage(Language.LABEL_REMOTE_CONTACT));
        jLabel1.setFont(font);
        jLabel1.setBounds(xlab, y, wlab, hlab);
        jLabel1.setVerticalAlignment(SwingConstants.CENTER);
        jpUp.add(jLabel1);

        jtContact.setText("");
        jtContact.setFont(font);
        jtContact.setBounds(xtext, y, wtext, htext);
        jtContact.requestFocusInWindow();
        jpUp.add(jtContact);

        y +=dy;

        jLabel2.setText(Language.getMessage(Language.LABEL_REMOTE_CALENDAR));
        jLabel2.setFont(font);
        jLabel2.setBounds(xlab, y, wlab, hlab);
        jLabel2.setVerticalAlignment(SwingConstants.CENTER);
        jpUp.add(jLabel2);

        jtCalendar.setText("");
        jtCalendar.setFont(font);
        jtCalendar.setBounds(xtext, y, wtext, htext);
        jpUp.add(jtCalendar);

        y +=dy;

        jLabel3.setText(Language.getMessage(Language.LABEL_REMOTE_NOTE));
        jLabel3.setFont(font);
        jLabel3.setBounds(xlab, y, wlab, hlab);
        jLabel3.setVerticalAlignment(SwingConstants.CENTER);
        jLabel3.setVisible(false);
        jpUp.add(jLabel3);

        jtNote.setText("");
        jtNote.setFont(font);
        jtNote.setBounds(xtext, y, wtext, htext);
        jtNote.setVisible(false);
        jpUp.add(jtNote);

        jpOver.add(jpUp);

        btOk.setText(Language.getMessage(Language.BT_OK));
        btOk.setActionCommand("OK");
        btOk.setName("btOk");
        btOk.setFont(font);
        btOk.setBounds(112, ybt, wbt, hbt);
        btOk.addActionListener(this);

        jpOver.add(btOk);

        btCancel.setText(Language.getMessage(Language.BT_CANCEL));
        btCancel.setActionCommand("CANCEL");
        btCancel.setName("btCancel");
        btCancel.setBounds(210, ybt, wbt, hbt);
        btCancel.setFont(font);
        btCancel.addActionListener(this);
        jpOver.add(btCancel);

        jtContact.setNextFocusableComponent(jtCalendar);
        jtCalendar.setNextFocusableComponent(jtNote)   ;
        jtNote.setNextFocusableComponent(btOk)         ;
        btOk.setNextFocusableComponent(btCancel)       ;
        btCancel.setNextFocusableComponent(jtContact)  ;
    }

    public void actionPerformed(ActionEvent evt) {
        if (evt.getActionCommand().equals("OK")) {
            htFields.put(PARAM_SOURCEURICONTACT , jtContact.getText() );
            htFields.put(PARAM_SOURCEURICALENDAR, jtCalendar.getText());
            htFields.put(PARAM_SOURCEURINOTE    , jtNote.getText()    );

            mainWindow.writeRemoteSettings(htFields);

            removeAll();
            setVisible(false);
        } else if (evt.getActionCommand().equals("CANCEL")) {
            removeAll();
            setVisible(false);
        }
    }

    /**
     * Sets the fields with some of the values contained
     * in the specified Hashtables.
     */
    private void setRemoteConfigStored() {

        String contactSourceURI  = (String)htContactValues.get(PARAM_SYNCSOURCEURI);
        String calendarSourceURI = (String)htCalendarValues.get(PARAM_SYNCSOURCEURI);
        String noteSourceURI     = (String)htNoteValues.get(PARAM_SYNCSOURCEURI);

        htFields.put(PARAM_SOURCEURICONTACT , contactSourceURI );
        htFields.put(PARAM_SOURCEURICALENDAR, calendarSourceURI);
        htFields.put(PARAM_SOURCEURINOTE    , noteSourceURI    );

        jtContact.setText(contactSourceURI);
        jtCalendar.setText(calendarSourceURI);
        jtNote.setText(noteSourceURI);
    }
}
