/**
 * Copyright (C) 2005-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.funambol.syncclient.ipod.panels;

import com.funambol.syncclient.ipod.utils.Constants;
import com.funambol.syncclient.ipod.utils.Language;
import java.util.Hashtable;
import java.io.File;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.ButtonGroup;
import javax.swing.JComboBox;
import javax.swing.JCheckBox;
import javax.swing.JRadioButton;
import javax.swing.JLabel;
import javax.swing.UIManager;
import javax.swing.border.*;
import javax.swing.SwingConstants;

import com.funambol.syncclient.ipod.MainWindow;

/**
 * The Synchronization settings window.
 *
 * @version $Id: SyncSetPanel.java,v 1.1 2006/01/18 14:05:35 luigiafassina Exp $
 */
public class SyncSetPanel extends JDialog implements ActionListener, Constants {

    // ------------------------------------------------------------ Private Data
    private Hashtable  htFields = new Hashtable();
    private MainWindow mainWindow ;
    private boolean modal = false ;

    private JButton      btRemoteSet;
    private JCheckBox    cbContacts ;
    private JCheckBox    cbCalendars;
    private JCheckBox    cbNotes    ;
    private JPanel       jpOver     ;
    private JPanel       jpUp       ;
    private JPanel       jpDown     ;
    private JButton      btOk       ;
    private JButton      btCancel   ;
    private JLabel       jLabel     ;
    private JLabel       jLabel2    ;
    private JComboBox    jcDriver   ;
    private JRadioButton jrNoneLog  ;
    private JRadioButton jrInfoLog  ;
    private JRadioButton jrDebugLog ;

    private Hashtable htContactValues  = null;
    private Hashtable htCalendarValues = null;
    private Hashtable htNoteValues     = null;
    private Hashtable htSyncmlValues   = null;

    // ---------------------------------------------------------- Public Methods

    /** Creates new form JDialog */
    public SyncSetPanel(MainWindow mainWindow, boolean modal) {
        super(mainWindow, modal);
        this.mainWindow = mainWindow;
        this.modal      = modal     ;

        htContactValues  = mainWindow.getXmlContactValues() ;
        htCalendarValues = mainWindow.getXmlCalendarValues();
        htNoteValues     = mainWindow.getXmlNoteValues()    ;
        htSyncmlValues   = mainWindow.getSyncmlValues()     ;

        initComponents();
        setSyncConfigStored();
    }

    /**
     * This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {
        int xcb = 10 ;
        int wcb = 80 ;
        int hcb = 23 ;
        int ybt = 235;
        int wbt = 88 ;
        int hbt = 24 ;

        jpOver      = new JPanel()   ;
        cbContacts  = new JCheckBox();
        cbCalendars = new JCheckBox();
        cbNotes     = new JCheckBox();
        btRemoteSet = new JButton()  ;
        jpUp        = new JPanel()   ;
        jpDown      = new JPanel()   ;
        btOk        = new JButton()  ;
        btCancel    = new JButton()  ;
        jLabel      = new JLabel()   ;
        jLabel2     = new JLabel()   ;
        jrNoneLog   = new JRadioButton();
        jrInfoLog   = new JRadioButton();
        jrDebugLog  = new JRadioButton();

        try {
            UIManager.setLookAndFeel(lookAndFeel);
        } catch(Exception e) {
            e.printStackTrace();
        }

        //
        // Set up the window.
        //
        getContentPane().setLayout(null);
        setTitle(Language.getMessage(Language.LABEL_TITLE_SYNCSETWINDOW));
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setSize(310,310);
        setLocationRelativeTo(null);
        setFont(font);
        setName("syncSetDialog");
        setResizable(false);

        jpOver.setLayout(null);
        jpOver.setBackground(Color.WHITE);
        jpOver.setForeground(Color.WHITE);
        jpOver.setBounds(0, 0, 310, 310);
        getContentPane().add(jpOver);

        //
        // Internal panel for Synchronization Settings
        //
        jpUp.setLayout(null);
        jpUp.setBounds(8, 16, 290, 129);
        jpUp.setBackground(Color.WHITE);
        jpUp.setBorder(new TitledBorder(
                            new LineBorder(new Color(204,204,204), 1, true),
                            Language.getMessage(Language.LABEL_TITLE_SYNCSETWINDOW),
                            1,
                            0,
                            font,
                            new Color(0,51,204))
        );
        jpUp.setName("syncSet");

        cbContacts.setText(Language.getMessage(Language.LABEL_SYNCSET_CONTACTS));
        cbContacts.setName("cbContacts");
        cbContacts.setFont(font);
        cbContacts.setBackground(Color.WHITE);
        cbContacts.setBounds(xcb, 22, wcb, hcb);
        cbContacts.setSelected(true);
        cbContacts.setVerticalAlignment(SwingConstants.CENTER);
        cbContacts.requestFocusInWindow();
        cbContacts.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                cbContactsActionPerformed();
            }
        });
        jpUp.add(cbContacts);

        cbCalendars.setText(Language.getMessage(Language.LABEL_SYNCSET_CALENDARS));
        cbCalendars.setName("cbCalendars");
        cbCalendars.setFont(font);
        cbCalendars.setBackground(Color.WHITE);
        cbCalendars.setBounds(xcb, 45, wcb, hcb);
        cbCalendars.setSelected(true);
        cbCalendars.setVerticalAlignment(SwingConstants.CENTER);
        cbCalendars.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                cbCalendarsActionPerformed();
            }
        });
        jpUp.add(cbCalendars);

        cbNotes.setText(Language.getMessage(Language.LABEL_SYNCSET_NOTES));
        cbNotes.setName("cbNotes");
        cbNotes.setFont(font);
        cbNotes.setBackground(Color.WHITE);
        cbNotes.setBounds(xcb, 67, wcb, hcb);
        cbNotes.setSelected(false);
        cbNotes.setVerticalAlignment(SwingConstants.CENTER);
        cbNotes.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                cbNotesActionPerformed();
            }
        });
        cbNotes.setVisible(false);
        jpUp.add(cbNotes);

        btRemoteSet.setActionCommand("REMOTESET");
        btRemoteSet.setName("btRemoteSet");
        btRemoteSet.setFont(font);
        btRemoteSet.setBounds(176, 45, wbt, hbt);
        btRemoteSet.setText(Language.getMessage(Language.BT_REMOTE_SET));
        btRemoteSet.setHorizontalTextPosition(SwingConstants.LEFT);
        btRemoteSet.setVerticalAlignment(SwingConstants.CENTER);
        btRemoteSet.setMargin(new java.awt.Insets(2, 1, 2, 1));
        btRemoteSet.addActionListener(this);

        jpUp.add(btRemoteSet);

        jpOver.add(jpUp);

        jpDown.setLayout(null);
        jpDown.setBackground(Color.WHITE);
        jpDown.setBounds(8, 149, 290, 80);
        jpDown.setBorder(new TitledBorder(
                            new LineBorder(new Color(204,204,204), 1, true),
                            Language.getMessage(Language.LABEL_SYNCSET_OTHER),
                            1,
                            0,
                            font,
                            new Color(0,51,204))
        );

        //
        // List of drivers: select that of the IPod
        //
        jLabel.setText(Language.getMessage(Language.LABEL_SYNCSET_DRIVE));
        jLabel.setFont(font);
        jLabel.setVerticalAlignment(SwingConstants.CENTER);
        jLabel.setBounds(10, 15, 90, 23);
        jpDown.add(jLabel);

        jcDriver = new JComboBox(File.listRoots());
        jcDriver.setBounds(110,15,100,23);
        jcDriver.setEditable(false);
        jcDriver.setSelectedIndex(0);
        jcDriver.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jcDriverActionPerformed(evt);
            }
        });
        jpDown.add(jcDriver);

        //
        // Radio button for logging level
        //
        jLabel2.setText(Language.getMessage(Language.LABEL_SYNCSET_LOGLEVEL));
        jLabel2.setFont(font);
        jLabel2.setVerticalAlignment(SwingConstants.CENTER);
        jLabel2.setBounds(10, 45, 90, 23);
        jpDown.add(jLabel2);

        jrNoneLog.setSelected(true);
        jrNoneLog.setText(Language.getMessage(Language.LABEL_SYNCSET_LOGNONE));
        jrNoneLog.setFont(font);
        jrNoneLog.setBackground(Color.WHITE);
        jrNoneLog.setBounds(105,45,55,20);
        jrNoneLog.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jrNoneLogActionPerformed();
            }
        });
        jpDown.add(jrNoneLog);

        jrInfoLog.setSelected(false);
        jrInfoLog.setText(Language.getMessage(Language.LABEL_SYNCSET_LOGINFO));
        jrInfoLog.setFont(font);
        jrInfoLog.setBackground(Color.WHITE);
        jrInfoLog.setBounds(165,45,50,20);
        jrInfoLog.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jrInfoLogActionPerformed();
            }
        });
        jpDown.add(jrInfoLog);

        jrDebugLog.setSelected(false);
        jrDebugLog.setText(Language.getMessage(Language.LABEL_SYNCSET_LOGDEBUG));
        jrDebugLog.setFont(font);
        jrDebugLog.setBackground(Color.WHITE);
        jrDebugLog.setBounds(215,45,60,20);
        jrDebugLog.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                jrDebugLogActionPerformed();
            }
        });
        jpDown.add(jrDebugLog);

        //
        //Group the radio buttons.
        //
        ButtonGroup group = new ButtonGroup();
        group.add(jrNoneLog);
        group.add(jrInfoLog);
        group.add(jrDebugLog);

        jpOver.add(jpDown);

        btOk.setText(Language.getMessage(Language.BT_OK));
        btOk.setActionCommand("OK");
        btOk.setName("btOk");
        btOk.setFont(font);
        btOk.setBounds(112, ybt, wbt, hbt);
        btOk.addActionListener(this);

        jpOver.add(btOk);

        btCancel.setText(Language.getMessage(Language.BT_CANCEL));
        btCancel.setActionCommand("CANCEL");
        btCancel.setName("btCancel");
        btCancel.setBounds(210, ybt, wbt, hbt);
        btCancel.setFont(font);
        btCancel.addActionListener(this);
        jpOver.add(btCancel);

        cbContacts.setNextFocusableComponent(cbCalendars);
        cbCalendars.setNextFocusableComponent(cbNotes)   ;
        cbNotes.setNextFocusableComponent(jcDriver)      ;
        jcDriver.setNextFocusableComponent(jrNoneLog)    ;
        jrNoneLog.setNextFocusableComponent(jrInfoLog)  ;
        jrInfoLog.setNextFocusableComponent(jrDebugLog)  ;
        jrDebugLog.setNextFocusableComponent(btRemoteSet);
        btRemoteSet.setNextFocusableComponent(btOk)      ;
        btOk.setNextFocusableComponent(btCancel)         ;
        btCancel.setNextFocusableComponent(cbContacts)   ;
    }

    private void cbContactsActionPerformed() {
        if (cbContacts.isSelected()) {
            htFields.put(PARAM_SYNCCONTACT, SYNC_TWOWAY);
        } else {
            htFields.put(PARAM_SYNCCONTACT, SYNC_NONE);
        }
    }

    private void cbCalendarsActionPerformed() {
        if (cbCalendars.isSelected()) {
            htFields.put(PARAM_SYNCCALENDAR, SYNC_TWOWAY);
        } else {
            htFields.put(PARAM_SYNCCALENDAR, SYNC_NONE);
        }
    }

    private void cbNotesActionPerformed() {
        if (cbNotes.isSelected()) {
            htFields.put(PARAM_SYNCNOTE, SYNC_TWOWAY);
        } else {
            htFields.put(PARAM_SYNCNOTE, SYNC_NONE);
        }
    }

    private void jrNoneLogActionPerformed() {
        if (jrNoneLog.isSelected()) {
            htFields.put(PARAM_LOGLEVEL, LOG_NONE);
        }
    }
    private void jrInfoLogActionPerformed() {
        if (jrInfoLog.isSelected()) {
            htFields.put(PARAM_LOGLEVEL, LOG_INFO);
        }
    }
    private void jrDebugLogActionPerformed() {
        if (jrDebugLog.isSelected()) {
            htFields.put(PARAM_LOGLEVEL, LOG_DEBUG);
        }
    }

    public void jcDriverActionPerformed(ActionEvent e) {
        JComboBox cb = (JComboBox)e.getSource();
        String driverSel = ((File)cb.getSelectedItem()).getPath();
        htFields.put(PARAM_SYNCSOURCEDRIVE, driverSel);
    }

    public void actionPerformed(ActionEvent evt) {
        if (evt.getActionCommand().equals("OK")) {
            mainWindow.writeSyncSettings(htFields);
            removeAll();
            setVisible(false);
        } else if (evt.getActionCommand().equals("CANCEL")) {
            removeAll();
            setVisible(false);
        } else if (evt.getActionCommand().equals("REMOTESET")) {
            RemoteSetPanel esp = new RemoteSetPanel(mainWindow,modal);
            esp.show();
        }
    }

    /**
     * Sets the fields with some of the values contained
     * in the specified Hashtables.
     */
    private void setSyncConfigStored() {

        String contactSyncMode  = (String)htContactValues.get(PARAM_SYNCMODE) ;
        String calendarSyncMode = (String)htCalendarValues.get(PARAM_SYNCMODE);
        String noteSyncMode     = (String)htNoteValues.get(PARAM_SYNCMODE)    ;
        String sourceDrive      = (String)htContactValues.get(PARAM_SYNCSOURCEDRIVE);
        String logLevel         = (String)htSyncmlValues.get(PARAM_LOGLEVEL);

        htFields.put(PARAM_SYNCCONTACT , contactSyncMode );
        htFields.put(PARAM_SYNCCALENDAR, calendarSyncMode);
        htFields.put(PARAM_SYNCNOTE    , noteSyncMode    );

        htFields.put(PARAM_LOGLEVEL    , logLevel        );

        if (SYNC_TWOWAY.equals(contactSyncMode)) {
            cbContacts.setSelected(true);
        } else {
            cbContacts.setSelected(false);
        }

        if (SYNC_TWOWAY.equals(calendarSyncMode)) {
            cbCalendars.setSelected(true);
        } else {
            cbCalendars.setSelected(false);
        }

        if (SYNC_TWOWAY.equals(noteSyncMode)) {
            cbNotes.setSelected(true);
        } else {
            cbNotes.setSelected(false);
        }

        if(logLevel.equals(LOG_NONE)) {
            jrNoneLog.setSelected(true);
        } else if(logLevel.equals(LOG_INFO)) {
            jrInfoLog.setSelected(true);
        } else if(logLevel.equals(LOG_DEBUG)) {
            jrDebugLog.setSelected(true);
        }

        if (sourceDrive != null) {
            htFields.put(PARAM_SYNCSOURCEDRIVE, sourceDrive);
            jcDriver.setSelectedItem(new File(sourceDrive));
        } else {
            jcDriver.setSelectedIndex(0);                        
            String driverDefault = ((File)jcDriver.getSelectedItem()).getPath();
            htFields.put(PARAM_SYNCSOURCEDRIVE, driverDefault);
        }
    }
}